//	Actor.cpp - Base class for all Actors.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Actor.h"
#include "Random.h"
#include "MiscHelper.h"

using namespace std;

//------------------------------------------------------------------------------
Actor::Actor(const Stats& startingStats):
stats(startingStats)
{
	health = stats.health;
};

//------------------------------------------------------------------------------
Actor::~Actor()
{

}

//------------------------------------------------------------------------------
int Actor::attacked(const shared_ptr<Actor>& other)
{
	int attackVal;
	const Stats& otherStats = other->getStats();

	attackVal = randomVal(otherStats.hitPower);
	attackVal += (int)((float)randomVal(otherStats.speed) * 0.15f);
	attackVal -= (randomVal(stats.speed)+randomVal(stats.absorption))/2;
	if(attackVal < 1)
		attackVal = 1;

	updateHealth(-attackVal);

	return attackVal;
}

//------------------------------------------------------------------------------
void Actor::setPosition(const TwoFloats& pos)
{
	position = pos;	
}

//------------------------------------------------------------------------------
void Actor::updateHealth(int val)
{
	health += val;
	if(health > stats.health)
		health = stats.health;
	if(health < 0)
		health = 0;
}

//------------------------------------------------------------------------------
int Actor::randomVal(int range)
{
	int retval;

	retval = (int)(fakeLog(Random::getGlobal().getRandomFloat()) * (float)range);

	return retval;
}
