//	Actor.h - Base class for all Actors.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ACTOR_H_
#define ACTOR_H_

#include "Stats.h"
#include "TwoFloats.h"

#include <string>
#include <memory>

class Drawer;

///	Base class for all Actors.
class Actor
{
  public:
	///	Constructor.
	Actor(const Stats& startingStats);
	///	Destructor.
	virtual ~Actor();

	///	Draws the actor.
	virtual void draw(Drawer *d, const TwoFloats& pos, float scale) = 0;

	///	Called when one Actor attacks this one.
	/*!
		\return The amount of damage inflicted.
	 */
	int attacked(const std::shared_ptr<Actor>& other);

	///	Returns the actor's position.
	const TwoFloats& getPosition() const {return position;};
	///	Sets the actor's position.
	void setPosition(const TwoFloats& pos);

	///	Updates the actor's health.
	/*!
		\param val This value is added to the actor's health.
	 */
	void updateHealth(int val);

	///	Returns the actor's name.
	virtual const std::string& getName() const = 0;
	///	Returns the actor's stats.
	Stats& getStats() {return stats;};
	///	Returns the actor's heatlth.
	/*!
		\return 0->stats.health.
	 */
	virtual int getHealth() const {return health;};
  private:
	///	Simple helper method used by attacked().
	int randomVal(int range);

	///	The actor's position.
	TwoFloats position;
	///	The actor's health.
	int health;

	///	The actor's stats.
	Stats stats;
};

#endif
