//	AnimalActor.cpp - Actor representing an Animal.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "AnimalActor.h"
#include "NiallsDrawingLib/Drawer.h"

#include <cassert>

using namespace std;

//------------------------------------------------------------------------------
AnimalActor::AnimalActor(const string& animalName,
						 const Stats& stats,
						 uint32_t animalImage):
Actor(stats),
name(animalName),
image(animalImage),
dead(false)
{

}

//------------------------------------------------------------------------------
AnimalActor::~AnimalActor()
{

}

//------------------------------------------------------------------------------
void AnimalActor::draw(Drawer *d, const TwoFloats& pos, float scale)
{
	assert(image != 0);

	d->drawImage(image, pos.x, pos.y, scale, scale);
}

//------------------------------------------------------------------------------
void AnimalActor::setDead()
{
	dead = true;
	setPosition(TwoFloats(-1, -1));
}

//------------------------------------------------------------------------------
bool AnimalActor::addEquippedItem(std::shared_ptr<Item>& item)
{
	bool retval = false;

	if(item && !equippedItem)
	{
		equippedItem = item;
		retval = true;

		getStats() += item->stats;
	}
	else if(!item && equippedItem)
	{
		getStats() += equippedItem->stats;

		equippedItem.reset();
		retval = true;
	}

	return retval;
}
