//	AnimalActor.h - Actor representing an Animal.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ANIMALACTOR_H_
#define ANIMALACTOR_H_

#include "Actor.h"
#include "Item.h"

#include <memory>
#include <vector>
#include <stdint.h>

///	Actor representing an Animal.
class AnimalActor : public Actor
{
  public:
	///	Constructor.
	AnimalActor(const std::string& animalName,
				const Stats& stats,
				uint32_t animalImage);
	///	Destructor.
	~AnimalActor();

	///	Draws the actor.
	void draw(Drawer *d, const TwoFloats& pos, float scale);

	///	Marks the Animal as dead, and not part of the battle.
	void setDead();
	///	Returns true if the Animal is dead.
	bool getDead() const {return dead;};

	///	Adds an Item to this Actor's equipment slot.
	/*!
		\return Returns true if the item was equipped.
	 */
	bool addEquippedItem(std::shared_ptr<Item>& item);
	///	Returns the Item in this Actor's equipment slot.
	const std::shared_ptr<Item>& getEquippedItem() const {return equippedItem;};

	///	Returns the actor's name.
	const std::string& getName() const {return name;};
  private:
	///	The animal's name.
	std::string name;

	///	The animal's image.
	uint32_t image;

	///	The item in the animal's equipment slot.
	std::shared_ptr<Item> equippedItem;
	///	The animal's inventory.
	std::vector<std::shared_ptr<Item> > inventory;

	///	True if the animal is dead.
	bool dead;
};

#endif
