//	AnimalActorOver.h - Overworld Actor representing an Animal.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ANIMALACTOROVER_H_
#define ANIMALACTOROVER_H_

#include "AnimalActor.h"

#include <stdint.h>
#include <memory>

///	Overworld Actor representing an Animal.
class AnimalActorOver : public Actor
{
  public:
	///	Constructor.
	AnimalActorOver(const std::string& animalName,
					const Stats& stats,
					uint32_t animalImage);
	///	Destructor.
	~AnimalActorOver();

	///	Draws the actor.
	void draw(Drawer *d, const TwoFloats& pos, float scale);

	///	Returns the actor's name.
	const std::string& getName() const {return animals[0]->getName();};
	///	Returns the actor's heatlth.
	virtual int getHealth() const {return (animals[0]->getHealth()+animals[1]->getHealth());};

	///	Returns the indexed AnimalActor this Overworld Actor contains.
	std::shared_ptr<AnimalActor>& getAnimal(int index) {return animals[index];};
	///	Returns the max health of this AnimActorOver's combined AnimalActors.
	int getMaxHealth() const {return (animals[0]->getStats().health * 2);};
  private:
	///	This Overworld Animal's two Animals.
	std::shared_ptr<AnimalActor> animals[2];
};

#endif
