//	BattleMap.cpp - Bits and pieces related to the battle map.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "BattleMap.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

//------------------------------------------------------------------------------
uint32_t BattleMap::tiles[BattleMap::NumTiles] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

//------------------------------------------------------------------------------
void BattleMap::loadTiles(Drawer *d)
{
	if(!tiles[1])
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::tilefield_png, Images::tilefield_pngSize);
		tiles[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tiletree_png, Images::tiletree_pngSize);
		tiles[2] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tilelake_png, Images::tilelake_pngSize);
		tiles[3] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tileroadvertical_png, Images::tileroadvertical_pngSize);
		tiles[4] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tileroadhorizontal_png, Images::tileroadhorizontal_pngSize);
		tiles[5] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tileroadcross_png, Images::tileroadcross_pngSize);
		tiles[6] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tilehouse_png, Images::tilehouse_pngSize);
		tiles[7] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tileskyscraper_png, Images::tileskyscraper_pngSize);
		tiles[8] = d->loadImage(data.data, data.width, data.height);
	}
}

//------------------------------------------------------------------------------
void BattleMap::drawMap(Drawer *d, BattleMap::Map map)
{
	int x, y;

	if(!tiles[1])
		loadTiles(d);

	for(y=0;y<BattleMap::MapHeight;++y)
	{
		for(x=0;x<BattleMap::MapWidth;++x)
		{
			BattleMap::Tile tile = map[(y*BattleMap::MapWidth)+x];

			if(tile != BattleMap::Grass)
				d->drawImage(tiles[(int)tile], (x*128.0f), (y*128.0f));
		}
	}
}
