//	BattleMap.h - Bits and pieces related to the battle map.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef BATTLEMAP_H_
#define BATTLEMAP_H_

#include <stdint.h>
#include <array>

class Drawer;

///	Bits and pieces related to the battle map.
namespace BattleMap
{
	///	Indices of the different map tiles.
	enum Tile
	{
		Grass = 0, //No tile for this; it just uses the background.
		Field,
		Tree,
		Lake,
		RoadVert,
		RoadHoriz,
		RoadCross,
		House,
		Skyscraper,

		NumTiles
	};

	///	The dimensions of the overworld map.
	enum
	{
		MapWidth = 10,
		MapHeight = 5
	};

	///	For a bit less typing.
	typedef std::array<BattleMap::Tile, (BattleMap::MapWidth*BattleMap::MapHeight)> Map;

	///	Overworld map images.
	extern uint32_t tiles[NumTiles];

	///	Loads the battle map tiles.
	void loadTiles(Drawer *d);

	///	Draws an battle map.
	void drawMap(Drawer *d, Map map);
};

#endif
