//	BattleMapGenerator.cpp - Generators for the different battle maps.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "BattleMapGenerators.h"
#include "Random.h"

using namespace BattleMap;
using namespace std;

//------------------------------------------------------------------------------
BattleMapGenerator::BattleMapGenerator()
{

}

//------------------------------------------------------------------------------
BattleMapGenerator::~BattleMapGenerator()
{

}

//------------------------------------------------------------------------------
Map BattleMapGenerator::generateGrassMap()
{
	int i, j;
	int x, y;
	Map retval;
	bool foundTile;

	//Clear everything to grass.
	for(i=0;i<(MapWidth*MapHeight);++i)
		retval[i] = Grass;

	for(i=0;i<3;++i)
	{
		int numTiles;
		Tile currentTile = (Tile)(i+1);

		//Determine how many of these tiles we're going to generate.
		if(currentTile == Field)
			numTiles = 4 + (int)(Random::getGlobal().getRandomFloat() * 2.99f);
		else
			numTiles = 3 + (int)(Random::getGlobal().getRandomFloat() * 1.99f);

		//Add them to the map.
		for(j=0;j<numTiles;++j)
		{
			int infiniteLoopCounter = 15;

			foundTile = false;
			while(!foundTile)
			{
				x = 1 + (int)(Random::getGlobal().getRandomFloat() * ((float)(MapWidth-2)-0.01f));
				y = 1 + (int)(Random::getGlobal().getRandomFloat() * ((float)(MapHeight-2)-0.01f));

				if((retval[(y*MapWidth)+x] == Grass)) //There isn't already a non-grass tile here.
				{
					/*if(x > 0)
					{
						if(retval[(y*MapWidth)+x-1] != Grass)
							continue;
					}
					if(x < (MapWidth-1))
					{
						if(retval[(y*MapWidth)+x+1] != Grass)
							continue;
					}
					if(y > 0)
					{
						if(retval[((y-1)*MapWidth)+x] != Grass)
							continue;
					}
					if(y < (MapHeight-1))
					{
						if(retval[((y+1)*MapWidth)+x] != Grass)
							continue;
					}*/
					
					retval[(y*MapWidth)+x] = currentTile;
					foundTile = true;
				}

				--infiniteLoopCounter;
				if(infiniteLoopCounter < 0)
					break;
			}
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
Map BattleMapGenerator::generateFieldMap()
{
	int i, j;
	int x, y;
	Map retval;
	bool foundTile;

	//Clear everything to grass.
	for(i=0;i<(MapWidth*MapHeight);++i)
		retval[i] = Grass;

	for(i=0;i<2;++i)
	{
		int numTiles;
		Tile currentTile = (Tile)(i+1);

		//Determine how many of these tiles we're going to generate.
		if(currentTile == Field)
			numTiles = 16 + (int)(Random::getGlobal().getRandomFloat() * 7.99f);
		else
			numTiles = 3 + (int)(Random::getGlobal().getRandomFloat() * 1.99f);

		//Add them to the map.
		for(j=0;j<numTiles;++j)
		{
			int infiniteLoopCounter = 15;

			foundTile = false;
			while(!foundTile)
			{
				x = 1 + (int)(Random::getGlobal().getRandomFloat() * ((float)(MapWidth-2)-0.01f));
				y = 1 + (int)(Random::getGlobal().getRandomFloat() * ((float)(MapHeight-2)-0.01f));

				if((retval[(y*MapWidth)+x] == Grass)) //There isn't already a non-grass tile here.
				{
					retval[(y*MapWidth)+x] = currentTile;
					foundTile = true;
				}

				--infiniteLoopCounter;
				if(infiniteLoopCounter < 0)
					break;
			}
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
Map BattleMapGenerator::generateForestMap()
{
	int i;
	int x, y;
	Map retval;
	int numPaths;

	//Clear everything to grass.
	for(i=0;i<(MapWidth*MapHeight);++i)
		retval[i] = Grass;

	//Add in trees.
	for(y=1;y<(MapHeight-1);++y)
	{
		for(x=1;x<(MapWidth-1);++x)
			retval[(y*MapWidth)+x] = Tree;
	}

	//Add paths through the trees.
	numPaths = 3 + (int)(Random::getGlobal().getRandomFloat() * 3.99f);
	for(i=0;i<numPaths;++i)
	{
		if(Random::getGlobal().getRandomFloat() > 0.33f)
		{
			x = 1 + (int)(Random::getGlobal().getRandomFloat() * (float)(MapWidth-2.01f));
			for(y=0;y<MapHeight;++y)
				retval[(y*MapWidth)+x] = Grass;
		}
		else 
		{
			y = 1 + (int)(Random::getGlobal().getRandomFloat() * (float)(MapHeight-2.01f));
			for(x=0;x<MapWidth;++x)
				retval[(y*MapWidth)+x] = Grass;
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
Map BattleMapGenerator::generateTownMap()
{
	int i, j;
	int x, y;
	Map retval;
	int numHouses;
	bool foundTile;

	//Clear everything to grass.
	for(i=0;i<(MapWidth*MapHeight);++i)
		retval[i] = Grass;

	//Fill outside of map with trees, fields and lakes.
	for(i=0;i<3;++i)
	{
		int numTiles;
		Tile currentTile = (Tile)(i+1);

		//Determine how many of these tiles we're going to generate.
		if(currentTile == Field)
			numTiles = 4 + (int)(Random::getGlobal().getRandomFloat() * 2.99f);
		else
			numTiles = 3 + (int)(Random::getGlobal().getRandomFloat() * 1.99f);

		//Add them to the map.
		for(j=0;j<numTiles;++j)
		{
			int infiniteLoopCounter = 15;

			foundTile = false;
			while(!foundTile)
			{
				x = (int)(Random::getGlobal().getRandomFloat() * ((float)MapWidth-0.01f));
				y = (int)(Random::getGlobal().getRandomFloat() * ((float)MapHeight-0.01f));

				if((retval[(y*MapWidth)+x] == Grass)) //There isn't already a non-grass tile here.
				{
					retval[(y*MapWidth)+x] = currentTile;
					foundTile = true;
				}

				--infiniteLoopCounter;
				if(infiniteLoopCounter < 0)
					break;
			}
		}
	}

	//Fill inside of map (6x3 square) with houses.
	numHouses = 4 + (int)(Random::getGlobal().getRandomFloat() * 3.99f);
	for(i=0;i<numHouses;++i)
	{
		x = 2 + (int)(Random::getGlobal().getRandomFloat() * 5.99f);
		y = 1 + (int)(Random::getGlobal().getRandomFloat() * 2.99f);

		retval[(y*MapWidth)+x] = House;
	}

	//Add in horizontal stretch of road.
	for(x=0;x<MapWidth;++x)
		retval[(2*MapWidth)+x] = RoadHoriz;
	//Add in vertical stretch of road.
	for(y=0;y<MapHeight;++y)
		retval[(y*MapWidth)+4] = RoadVert;
	//Add in RoadCross.
	retval[(2*MapWidth)+4] = RoadCross;

	return retval;
}

//------------------------------------------------------------------------------
Map BattleMapGenerator::generateCityMap()
{
	int i;
	int x, y;
	Map retval;

	//Fill with houses.
	for(y=0;y<MapHeight;++y)
	{
		for(x=0;x<MapWidth;++x)
			retval[(y*MapWidth)+x] = House;
	}

	//Add in skyscrapers.
	for(y=1;y<(MapHeight-1);++y)
	{
		for(x=1;x<(MapWidth-1);++x)
		{
			if(Random::getGlobal().getRandomFloat() > 0.5f)
				retval[(y*MapWidth)+x] = Skyscraper;
		}
	}

	//Add in horizontal roads.
	for(i=0;i<2;++i)
	{
		y = (int)(Random::getGlobal().getRandomFloat() * ((float)MapHeight-0.01f));
		for(x=0;x<MapWidth;++x)
			retval[(y*MapWidth)+x] = RoadHoriz;
	}

	//Add in vertical roads.
	for(i=0;i<4;++i)
	{
		x = (int)(Random::getGlobal().getRandomFloat() * (((float)MapWidth-0.01f)*0.5f));
		x *= 2;
		for(y=0;y<MapHeight;++y)
		{
			if(x > 0)
			{
				if(retval[(y*MapWidth)+x-1] == RoadHoriz)
					retval[(y*MapWidth)+x] = RoadCross;
				else
					retval[(y*MapWidth)+x] = RoadVert;
			}
			else if(x == 0)
			{
				if(retval[(y*MapWidth)+x+1] == RoadHoriz)
					retval[(y*MapWidth)+x] = RoadCross;
				else
					retval[(y*MapWidth)+x] = RoadVert;
			}
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
Map BattleMapGenerator::generateNullMap()
{
	int i;
	Map retval;

	//Clear everything to grass.
	for(i=0;i<(MapWidth*MapHeight);++i)
		retval[i] = Grass;

	return retval;
}
