//	BattleMapGenerators.h - Generators for the different battle maps.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef BATTLEMAPGENERATORS_H_
#define BATTLEMAPGENERATORS_H_

#include "BattleMap.h"

///	Generators for the different battle maps.
class BattleMapGenerator
{
  public:
	///	Constructor.
	BattleMapGenerator();
	///	Destructor.
	~BattleMapGenerator();

	///	Generates a grass-based battle map.
	/*!
		Returns an array BattleMap::MapWidth x BattleMap::MapHeight.
	 */
	BattleMap::Map generateGrassMap();
	///	Generates a field-based battle map.
	BattleMap::Map generateFieldMap();
	///	Generates a forest-based battle map.
	BattleMap::Map generateForestMap();
	///	Generates a town-based battle map.
	BattleMap::Map generateTownMap();
	///	Generates a city-based battle map.
	BattleMap::Map generateCityMap();
	///	Generates a blank battle map.
	BattleMap::Map generateNullMap();
};

#endif
