//	FadingText.h - Simple class for displaying some text and then fading it out.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef FADINGTEXT_H_
#define FADINGTEXT_H_

#include <string>
#include <stdint.h>

class Drawer;

///	Simple class for displaying some text and then fading it out.
class FadingText
{
  public:
	///	Constructor.
	FadingText();
	///	Destructor.
	~FadingText();

	///	Draws the text.
	void draw(Drawer *d);

	///	Sets the text's position.
	void setPosition(float x, float y, float w);
	///	Sets the text's colour.
	void setColour(float r, float g, float b);
	///	Sets the text's font.
	void setFont(uint32_t val);

	///	Triggers some text.
	void trigger(const std::string& t, float time = 240.0f);
  private:
	///	The text to draw.
	std::string text;
	///	The position to draw it.
	float xPos;
	///	The position to draw it.
	float yPos;
	///	The width of the box to fit it on.
	float width;
	///	The colour.
	float red;
	///	The colour.
	float green;
	///	The colour.
	float blue;
	///	The font.
	uint32_t font;
	///	The time for the text to stay on screen.
	float length;

	///	The index within length.
	float index;
};

#endif
