//	HumanActor.cpp - Actor representing a Human.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Random.h"
#include "HumanActor.h"
#include "NiallsDrawingLib/Drawer.h"

#include <cassert>

using namespace std;

//------------------------------------------------------------------------------
HumanActor::HumanActor(const string& humanName,
					   const Stats& stats,
					   uint32_t humanImage):
Actor(stats),
name(humanName),
image(humanImage),
dead(false)
{

}

//------------------------------------------------------------------------------
HumanActor::~HumanActor()
{

}

//------------------------------------------------------------------------------
void HumanActor::draw(Drawer *d, const TwoFloats& pos, float scale)
{
	assert(image != 0);

	d->drawImage(image, pos.x, pos.y, scale, scale);
}

//------------------------------------------------------------------------------
void HumanActor::move(const vector<shared_ptr<AnimalActor> >& animals,
					  const BattleMap::Map& map)
{
	int i;
	int tempint;
	float tempf;
	int nearest = 0;
	int compass = -1;
	float dist = 100.0f;
	TwoFloats animalPos;
	int infiniteLoopCounter = 0;
	TwoFloats newPos;
	const TwoFloats& humanPos = getPosition();

	if(!animals.size())
		return;

	//Find the nearest animal.
	for(i=0;i<animals.size();++i)
	{
		if(!animals[i]->getDead())
		{
			tempf = humanPos.getDistance(animals[i]->getPosition());
			if((tempf < dist) && (dist > 0.0f))
			{
				nearest = i;
				dist = tempf;
			}
		}
	}

	//Try to move towards it.
	animalPos = animals[nearest]->getPosition();
	if(animalPos.x > humanPos.x)
		newPos.x = 1.0f;
	else if(animalPos.x < humanPos.x)
		newPos.x = -1.0f;
	if(animalPos.y > humanPos.y)
		newPos.y = 1.0f;
	else if(animalPos.y < humanPos.y)
		newPos.y = -1.0f;

	if((newPos.x < 0.0f) && (newPos.y < 0.0f))
		newPos.y = 0.0f;
	else if((newPos.x > 0.0f) && (newPos.y < 0.0f))
		newPos.y = 0.0f;
	else if((newPos.x > 0.0f) && (newPos.y > 0.0f))
		newPos.x = 0.0f;
	else if((newPos.x < 0.0f) && (newPos.y > 0.0f))
		newPos.x = 0.0f;

	if((newPos.x == 0.0f) && (newPos.y ==-1.0f))
		compass = 0;
	else if((newPos.x == 1.0f) && (newPos.y == 0.0f))
		compass = 1;
	else if((newPos.x == 0.0f) && (newPos.y == 1.0f))
		compass = 2;
	else if((newPos.x == -1.0f) && (newPos.y == 0.0f))
		compass = 3;

	newPos += humanPos;
	if(newPos.x > (BattleMap::MapWidth-1))
		newPos.x = BattleMap::MapWidth-1;
	else if(newPos.x < 0)
		newPos.x = 0;
	if(newPos.y > (BattleMap::MapHeight-1))
		newPos.y = BattleMap::MapHeight-1;
	else if(newPos.y < 0)
		newPos.y = 0;

	if(compass < 0)
		return;

	tempf = Random::getGlobal().getRandomFloat();
	tempint = ((int)newPos.y * BattleMap::MapWidth)+(int)newPos.x;
	while((map[tempint] == BattleMap::Lake) || (map[tempint] == BattleMap::Tree))
	{
		if((newPos.x < 0.0f) || (newPos.x > (float)BattleMap::MapWidth) ||
		   (newPos.y < 0.0f) || (newPos.y > (float)BattleMap::MapHeight))
		{
			++infiniteLoopCounter;
			continue;
		}

		//Go either clockwise or anti-clockwise.
		if(tempf > 0.5f) //Clockwise.
		{
			++compass;
			compass %= 4;
		}
		else //Anti-clockwise.
		{
			--compass;
			if(compass < 0)
				compass += 4;
		}

		switch(compass)
		{
			case 0:
				newPos.x = 0.0f;
				newPos.y = -1.0f;
				break;
			case 1:
				newPos.x = 1.0f;
				newPos.y = 0.0f;
				break;
			case 2:
				newPos.x = 0.0f;
				newPos.y = 1.0f;
				break;
			case 3:
				newPos.x = -1.0f;
				newPos.y = 0.0f;
				break;
		}
		newPos += humanPos;
		if(newPos.x > (BattleMap::MapWidth-1))
			newPos.x = BattleMap::MapWidth-1;
		if(newPos.y > (BattleMap::MapHeight-1))
			newPos.y = BattleMap::MapHeight-1;
		tempint = ((int)newPos.y * BattleMap::MapWidth)+(int)newPos.x;

		if(infiniteLoopCounter > 3)
		{
			newPos = humanPos;
			break;
		}
	}
	setPosition(newPos);
}

//------------------------------------------------------------------------------
void HumanActor::setDead()
{
	dead = true;
	setPosition(TwoFloats(-1, -1));
}
