//	HumanActor.h - Actor representing a Human.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef HUMANACTOR_H_
#define HUMANACTOR_H_

#include "Actor.h"
#include "AnimalActor.h"
#include "BattleMap.h"

#include <vector>
#include <memory>
#include <stdint.h>

///	Actor representing a Human.
class HumanActor : public Actor
{
  public:
	///	Constructor.
	HumanActor(const std::string& humanName,
			   const Stats& stats,
			   uint32_t humanImage);
	///	Destructor.
	~HumanActor();

	///	Draws the actor.
	void draw(Drawer *d, const TwoFloats& pos, float scale);

	///	Moves the Human towards the nearest Animal.
	void move(const std::vector<std::shared_ptr<AnimalActor> >& animals,
			  const BattleMap::Map& map);

	///	Marks the Human as dead, and not part of the battle.
	void setDead();
	///	Returns true if the Human is dead.
	bool getDead() const {return dead;};

	///	Returns the actor's name.
	const std::string& getName() const {return name;};
  private:
	///	The human's name.
	std::string name;

	///	The human's image.
	uint32_t image;

	///	True if the human is dead.
	bool dead;
};

#endif
