//	HumanActorOver.h - Overworld Actor representing a Human.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef HUMANACTOROVER_H_
#define HUMANACTOROVER_H_

#include "HumanActor.h"
#include "AnimalActorOver.h"
#include "OverworldMap.h"

#include <vector>
#include <memory>
#include <stdint.h>

///	Overworld Actor representing a Human.
class HumanActorOver : public Actor
{
  public:
	///	Constructor.
	HumanActorOver(const std::string& humanName,
			   const Stats& stats,
			   uint32_t humanImage);
	///	Destructor.
	~HumanActorOver();

	///	Draws the actor.
	void draw(Drawer *d, const TwoFloats& pos, float scale);

	///	Moves the Human towards the nearest Animal.
	void move(const std::vector<std::shared_ptr<AnimalActorOver> >& animals,
			  const OverworldMap::Map& map);

	///	Returns the actor's name.
	const std::string& getName() const {return humans[0]->getName();};
	///	Returns the actor's heatlth.
	virtual int getHealth() const {return (humans[0]->getHealth()+humans[1]->getHealth());};

	///	Returns the indexed HumanActor this Overworld Actor contains.
	std::shared_ptr<HumanActor>& getHuman(int index) {return humans[index];};
	///	Returns the max health of this AnimActorOver's combined AnimalActors.
	int getMaxHealth() const {return (humans[0]->getStats().health * 2);};
  private:
	///	Helper method to calculate whether an Animal is standing on a Lake tile.
	bool isOnLake(const OverworldMap::Map& map, const TwoFloats& pos);

	///	This Overworld Human's two Humans.
	std::shared_ptr<HumanActor> humans[2];
};

#endif
