//	Item.cpp - Struct representing an Item.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Item.h"
#include "Random.h"

#include <sstream>

using namespace std;

//------------------------------------------------------------------------------
Item::Item(const TwoFloats& pos):
position(pos)
{
	int i;
	int tempStat;
	int numBoosts;
	stringstream tempstr;

	i = (int)(Random::getGlobal().getRandomFloat() * 9.99f);
	switch(i)
	{
		case 0:
			tempstr << "Cake of ";
			break;
		case 1:
			tempstr << "Foot of ";
			break;
		case 2:
			tempstr << "Horn of ";
			break;
		case 3:
			tempstr << "Lick of ";
			break;
		case 4:
			tempstr << "Helmet of ";
			break;
		case 5:
			tempstr << "Poem of ";
			break;
		case 6:
			tempstr << "Dirt of ";
			break;
		case 7:
			tempstr << "Hand of ";
			break;
		case 8:
			tempstr << "Waft of ";
			break;
		case 9:
			tempstr << "Branch of ";
			break;
	}

	i = (int)(Random::getGlobal().getRandomFloat() * 9.99f);
	switch(i)
	{
		case 0:
			tempstr << "Loathing";
			break;
		case 1:
			tempstr << "Wonder";
			break;
		case 2:
			tempstr << "Amazingness";
			break;
		case 3:
			tempstr << "Bad Smells";
			break;
		case 4:
			tempstr << "Simpletons";
			break;
		case 5:
			tempstr << "Dirt";
			break;
		case 6:
			tempstr << "Gold";
			break;
		case 7:
			tempstr << "Golfcart";
			break;
		case 8:
			tempstr << "Dung";
			break;
		case 9:
			tempstr << "Leaf";
			break;
	}

	name = tempstr.str();

	stats.hitPower = 0;
	stats.throwingPower = 0;
	stats.speed = 0;
	stats.absorption = 0;
	stats.intelligence = 0;
	stats.health = 0;
	stats.sightRadius = 0;
	stats.inventorySize = 0;
	stats.canSwim = 0;
	stats.canForest = 0;

	//If it's a health increase.
	if(Random::getGlobal().getRandomFloat() > 0.5f)
	{
		food = true;
		stats.health = 1 + (int)(Random::getGlobal().getRandomFloat() * 18.99f);
	}
	else //It's a stat boost.
	{
		food = false;
		//Determine stat boosts.
		numBoosts = 1 + (int)(Random::getGlobal().getRandomFloat() * 1.99f);
		for(i=0;i<numBoosts;++i)
		{
			tempStat = (int)(Random::getGlobal().getRandomFloat() * 9.99f);
			switch(tempStat)
			{
				case 0:
					stats.hitPower += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 1:
					stats.throwingPower += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 2:
					stats.speed += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 3:
					stats.absorption += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 4:
					stats.intelligence += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 5:
					stats.health += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 6:
					stats.sightRadius += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 7:
					stats.inventorySize += 1 + (int)(Random::getGlobal().getRandomFloat() * 9.99f);
					break;
				case 8:
					stats.canSwim = 1;
					break;
				case 9:
					stats.canForest = 1;
					break;
			}
		}
	}
}
