//	MessageBox.h - A simple message box.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef MESSAGEBOX_H_
#define MESSAGEBOX_H_

#include "TwoFloats.h"

#include <string>
#include <stdint.h>

class Drawer;

///	A simple message box.
class MessageBox
{
  public:
	///	Constructor.
	MessageBox();
	///	Destructor.
	~MessageBox();

	///	Draws the message box.
	void draw(Drawer *d,
			  uint32_t windowImage,
			  uint32_t buttonImage,
			  uint32_t font);

	///	Handles mouse events.
	void mouseMove(const TwoFloats& pos);
	///	Handles mouse events.
	void mouseUp(const TwoFloats& pos);

	///	Called to display the message box on screen.
	void display(const std::string& text);
	///	Returns whether or not the message box should be displayed.
	bool isVisible() const {return visible;};
  private:
	///	The message box's message.
	std::string message;
	///	Whether or not the message box is visible.
	bool visible;

	///	True if the mouse is over the button.
	bool mouseOver;
};

#endif
