//	MusicSingleton.h - Singleton class to switch between different tracks.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef MUSICSINGLETON_H_
#define MUSICSINGLETON_H_

#include <map>
#include <string>

class BackgroundMusic;

///	Singleton class to switch between different tracks.
class MusicSingleton
{
  public:
	///	Returns the sole instance of the singleton.
	static MusicSingleton& getInstance();

	///	Adds a track to the map of available tracks.
	/*!
		\param name The filename (minus path) of the track (e.g. track.ogg).
	 */
	void addTrack(const std::string& name);
	///	Switches to the named track.
	/*!
		\param name The name of the track (what you passed in in addTrack(),
		minus the .ogg extension).
	 */
	void playTrack(const std::string& name);

	///	Fills a buffer with audio.
	void audioBlock(float *buffer, int numSamples);

	///	Mutes the music.
	void mute();

#ifdef WIN32
	///	Destructor.
	~MusicSingleton();
#endif
  private:
	///	Constructor.
	MusicSingleton();
#ifndef WIN32
	///	Destructor.
	~MusicSingleton();
#endif

	///	The available tracks.
	std::map<std::string, BackgroundMusic *> tracks;
	///	The currently playing track.
	std::string currentTrack;
	///	Whether the music's muted or not.
	bool isMuted;
};

#endif
