//	OverworldMap.cpp - Bits and pieces related to the overworld map.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "OverworldMap.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

//------------------------------------------------------------------------------
uint32_t OverworldMap::tiles[OverworldMap::NumTiles] = {0, 0, 0, 0, 0, 0, 0};

//------------------------------------------------------------------------------
void OverworldMap::loadTiles(Drawer *d)
{
	if(!tiles[1])
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::tilefield_png, Images::tilefield_pngSize);
		tiles[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tileforest_png, Images::tileforest_pngSize);
		tiles[2] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tilelake_png, Images::tilelake_pngSize);
		tiles[3] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tiletown_png, Images::tiletown_pngSize);
		tiles[4] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tilecity_png, Images::tilecity_pngSize);
		tiles[5] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::tilesafaripark_png, Images::tilesafaripark_pngSize);
		tiles[6] = d->loadImage(data.data, data.width, data.height);
	}
}

//------------------------------------------------------------------------------
void OverworldMap::drawMap(Drawer *d, OverworldMap::Map map)
{
	int x, y;

	if(!tiles[1])
		loadTiles(d);

	for(y=0;y<OverworldMap::MapHeight;++y)
	{
		for(x=0;x<OverworldMap::MapWidth;++x)
		{
			OverworldMap::Tile tile = map[(y*OverworldMap::MapWidth)+x];

			if(tile != OverworldMap::Grass)
				d->drawImage(tiles[(int)tile], (x*128.0f), (y*128.0f));
		}
	}
}
