//	OverworldMapGenerator.cpp - Generator for the overworld map.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "OverworldMapGenerator.h"
#include "Random.h"

using namespace OverworldMap;
using namespace std;

//------------------------------------------------------------------------------
OverworldMapGenerator::OverworldMapGenerator()
{

}

//------------------------------------------------------------------------------
OverworldMapGenerator::~OverworldMapGenerator()
{

}

//------------------------------------------------------------------------------
Map OverworldMapGenerator::generate()
{
	int i, j;
	int x, y;
	Map retval;
	bool foundTile;

	//Clear everything to grass.
	for(i=0;i<(MapWidth*MapHeight);++i)
		retval[i] = Grass;

	//Set the safari park.
	retval[(4*MapWidth) + 4] = SafariPark;

	for(i=0;i<5;++i)
	{
		int numTiles;
		Tile currentTile = (Tile)(i+1);

		//Determine how many of these tiles we're going to generate.
		if((currentTile != Town) && (currentTile != City))
			numTiles = 2 + (int)(Random::getGlobal().getRandomFloat() * 2.99f);
		else
			numTiles = 2 + (int)(Random::getGlobal().getRandomFloat() * 1.99f);

		//Add them to the map.
		for(j=0;j<numTiles;++j)
		{
			int infiniteLoopCounter = 15;

			foundTile = false;
			while(!foundTile)
			{
				x = (int)(Random::getGlobal().getRandomFloat() * ((float)MapWidth-0.01f));
				y = (int)(Random::getGlobal().getRandomFloat() * ((float)MapHeight-0.01f));

				if((retval[(y*MapWidth)+x] == Grass) && //There isn't already a non-grass tile here.
				   !((x == 3) && (y == 4)) && // \*
				   !((x == 5) && (y == 4)) && //  > It's not one of the tiles surrounding the safari park.
				   !((x == 4) && (y == 3))) // /
				{
					if(x > 0)
					{
						if(retval[(y*MapWidth)+x-1] != Grass)
							continue;
					}
					if(x < (MapWidth-1))
					{
						if(retval[(y*MapWidth)+x+1] != Grass)
							continue;
					}
					if(y > 0)
					{
						if(retval[((y-1)*MapWidth)+x] != Grass)
							continue;
					}
					if(y < (MapHeight-1))
					{
						if(retval[((y+1)*MapWidth)+x] != Grass)
							continue;
					}
					
					retval[(y*MapWidth)+x] = currentTile;
					foundTile = true;
				}

				--infiniteLoopCounter;
				if(infiniteLoopCounter < 0)
					break;
			}
		}
	}

	return retval;
}
