//	Stats.h - Animal/Human stats stored as constants.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef STATS_H_
#define STATS_H_

//------------------------------------------------------------------------------
///	Basic stats structure.
struct Stats
{
	int hitPower;
	int throwingPower;
	int speed;
	int absorption;
	int intelligence;
	int health;
	int sightRadius;
	int inventorySize;
	int canSwim; //0 or non-negative.
	int canForest; //0 or non-negative.

	Stats& operator+=(const Stats& other)
	{
		hitPower += other.hitPower;
		throwingPower += other.throwingPower;
		speed += other.speed;
		absorption += other.absorption;
		intelligence += other.intelligence;
		health += other.health;
		sightRadius += other.sightRadius;
		inventorySize += other.inventorySize;
		canSwim += other.canSwim;
		canForest += other.canForest;

		return *this;
	};

	Stats& operator-=(const Stats& other)
	{
		hitPower -= other.hitPower;
		throwingPower -= other.throwingPower;
		speed -= other.speed;
		absorption -= other.absorption;
		intelligence -= other.intelligence;
		health -= other.health;
		sightRadius -= other.sightRadius;
		inventorySize -= other.inventorySize;
		canSwim -= other.canSwim;
		canForest -= other.canForest;

		return *this;
	};
};

//------------------------------------------------------------------------------
namespace GlobalStats
{
	///	Default Animal stats.
	extern const Stats AnimalStats[6];

	///	Default Human stats.
	extern const Stats HumanStats[3];
};

#endif
