//	StatsDisplay.cpp - Simple tooltip displaying an Actor's stats.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2011  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "StatsDisplay.h"
#include "Stats.h"
#include "NiallsDrawingLib/Drawer.h"

#include <sstream>

using namespace std;

//------------------------------------------------------------------------------
StatsDisplay::StatsDisplay()
{

}

//------------------------------------------------------------------------------
StatsDisplay::~StatsDisplay()
{

}

//------------------------------------------------------------------------------
void StatsDisplay::draw(Drawer *d,
					    uint32_t font,
					    const string& actorName,
					    const Stats& stats,
					    const TwoFloats& pos)
{
	stringstream tempstr;
	TwoFloats tempPos = pos;

	if((tempPos.x+210) > 1280)
		tempPos.x = 1280-210;
	if(tempPos.y+264 > 720)
		tempPos.y = 720-264;

	d->fillRect(tempPos.x, tempPos.y, 210, 264, 0, 0, 0, 128);

	//Draw actor name.
	tempPos += 4;
	d->drawText(actorName, font, tempPos.x, tempPos.y, 256, 1.0f, 1.0f, 1.0f, 0.5f);

	//Draw actor's stats.
	tempPos.y += 32;
	tempstr << "Hit Power: " << stats.hitPower;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	tempPos.y += 22;
	tempstr << "Throwing Power: " << stats.throwingPower;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	tempPos.y += 22;
	tempstr << "Speed: " << stats.speed;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	tempPos.y += 22;
	tempstr << "Absorption: " << stats.absorption;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	tempPos.y += 22;
	tempstr << "Intelligence: " << stats.intelligence;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	tempPos.y += 22;
	tempstr << "Health: " << stats.health;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	tempPos.y += 22;
	tempstr << "Sight Radius: " << stats.sightRadius;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	tempPos.y += 22;
	tempstr << "Inventory Size: " << stats.inventorySize;
	d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
	tempstr.str("");

	if(stats.canSwim)
	{
		tempPos.y += 22;
		tempstr << "Can Swim";
		d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
		tempstr.str("");
	}

	if(stats.canForest)
	{
		tempPos.y += 22;
		tempstr << "Can Enter Forests";
		d->drawText(tempstr.str(), font, tempPos.x, tempPos.y, 256, 0.75f);
		tempstr.str("");
	}
}
