//	HorizontalSlider.cpp - A horizontal slider widget.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "HorizontalSlider.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "MouseCursor.h"

//------------------------------------------------------------------------------
HorizontalSlider::HorizontalSlider(const char *data,
								   uint32_t size,
								   float handleWidth):
Widget(),
ChangeBroadcaster(),
image(0),
value(0.0f),
handleSize(handleWidth),
dragging(false),
mouseIsOver(false),
imageData(data),
imageSize(size)
{
	
}

//------------------------------------------------------------------------------
HorizontalSlider::~HorizontalSlider()
{
	
}

//------------------------------------------------------------------------------
void HorizontalSlider::draw(Drawer *d)
{
	float tempf;

	if(!image)
	{
		ImageData data;
		ImageLoader loader;

		data = loader.loadImage(imageData, imageSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	tempf = value * getWidth();
	tempf += getXPos();
	tempf -= (handleSize*0.5f);

	d->drawImage(image, tempf, getYPos());
}

//------------------------------------------------------------------------------
void HorizontalSlider::mouseMove(float x, float y)
{
	float left, right;
	const float w = getWidth();

	mouseIsOver = true;
	MouseCursor::getInstance().setImage(true);

	left = getXPos();
	right = left + w;

	if(dragging)
	{
		if((x >= left) && (x < right))
			value = (x-left)/w;
		else if(x < left)
			value = 0.0f;
		else if(x > right)
			value = 1.0f;
		callChangeCallbacks(this, value);
	}
}

//------------------------------------------------------------------------------
void HorizontalSlider::mouseButton(bool val, float x, float y)
{
	float left, right;
	const float w = getWidth();

	if(val)
	{
		left = getXPos();
		right = left + w;

		if((x >= left) && (x < right))
		{
			value = (x-left)/w;
			dragging = true;
		}
	}
	else
		dragging = false;
}

//------------------------------------------------------------------------------
void HorizontalSlider::mouseLeave(float x, float y)
{
	float left, right;
	const float w = getWidth();

	if(!dragging && mouseIsOver)
	{
		mouseIsOver = false;
		MouseCursor::getInstance().setImage(false);
	}
	else if(dragging)
	{
		left = getXPos();
		right = left + w;

		if((x >= left) && (x < right))
			value = (x-left)/w;
		else if(x < left)
			value = 0.0f;
		else if(x > right)
			value = 1.0f;
		callChangeCallbacks(this, value);
	}
}

//------------------------------------------------------------------------------
void HorizontalSlider::setValue(float val)
{
	value = val;
}
