//	WidgetContainer.cpp - Base class for any containers of widgets.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "WidgetContainer.h"

using namespace std;

//------------------------------------------------------------------------------
WidgetContainer::WidgetContainer():
Widget()
{
	
}

//------------------------------------------------------------------------------
WidgetContainer::~WidgetContainer()
{
	removeAllChildren();
}

//------------------------------------------------------------------------------
void WidgetContainer::draw(Drawer *d)
{
	int i;

	for(i=0;i<children.size();++i)
		children[i]->draw(d);
}

//------------------------------------------------------------------------------
void WidgetContainer::mouseMove(float x, float y)
{
	int i;

	for(i=0;i<children.size();++i)
		children[i]->mouseMoveTest(x, y);
}

//------------------------------------------------------------------------------
void WidgetContainer::mouseButton(bool val, float x, float y)
{
	int i;

	for(i=0;i<children.size();++i)
		children[i]->mouseButtonTest(val, x, y);
}

//------------------------------------------------------------------------------
void WidgetContainer::mouseLeave(float x, float y)
{
	int i;

	for(i=0;i<children.size();++i)
		children[i]->mouseMoveTest(x, y);
}

//------------------------------------------------------------------------------
void WidgetContainer::addChild(Widget *w)
{
	children.push_back(w);
}

//------------------------------------------------------------------------------
void WidgetContainer::removeChild(Widget *w)
{
	int i;

	for(i=0;i<children.size();++i)
	{
		if(children[i] == w)
		{
			delete children[i];
			children.erase(children.begin()+i);
			break;
		}
	}
}

//------------------------------------------------------------------------------
void WidgetContainer::removeChild(int index)
{
	int i;

	for(i=0;i<children.size();++i)
	{
		if(i == index)
		{
			delete children[i];
			children.erase(children.begin()+i);
			break;
		}
	}
}

//------------------------------------------------------------------------------
void WidgetContainer::removeAllChildren()
{
	int i;

	for(i=(children.size()-1);i>=0;--i)
	{
		delete children[i];
		children.erase(children.begin()+i);
	}
}
