//	WidgetContainer.h - Base class for any containers of widgets.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef WIDGETCONTAINER_H_
#define WIDGETCONTAINER_H_

#include "Widget.h"

#include <vector>

///	Base class for any containers of widgets.
class WidgetContainer : public Widget
{
  public:
	///	Constructor.
	WidgetContainer();
	///	Destructor.
	~WidgetContainer();

	///	Draws the widget.
	void draw(Drawer *d);

	///	Called when the mouse moves within this widget's bounds
	void mouseMove(float x, float y);
	///	Called when a mouse button is clicked or released.
	void mouseButton(bool val, float x, float y);
	///	Called when the mouse is outside the widget's bounds.
	void mouseLeave(float x, float y);

	///	Adds a widget to this container.
	/*!
		Children added to this container will be deleted by the container.
	 */
	void addChild(Widget *w);
	///	Returns the number of widgets within this container.
	int getNumChildren() const {return children.size();};
	///	Removes a child widget matching w.
	void removeChild(Widget *w);
	///	Removes the indexed child widget.
	void removeChild(int index);
	///	Removes all child widgets.
	void removeAllChildren();
  private:
	///	The child widgets.
	std::vector<Widget *> children;
};

#endif
